<!--- SPDX-License-Identifier: Apache-2.0 -->

## Member Company logos

Member Companies as defined [here](readme.md#community-roles) can request their logo be displayed on https://onnx.ai and other materials.

To have your logo displayed, submit a PR to https://github.com/onnx/onnx.github.io with the following:
1. Text of the PR must include written permission indicating the logo can be used on the onnx.ai website as well as in presentations showing ONNX Member Companies
2. A high quality logo file with transparent background needs to be committed in the "assets" directory. The image file should be 300dpi (best if physical printing is ever required) or a vector file which can be saved in any resolution.
3. The URL of your company or product web page. Ideally the page mentions ONNX.

Member Companies may ask for their logo to be removed at any time and their status as Member Company rescinded. The Steering Committee also can vote to remove a Member Company of their status.
